<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Your email has now been validated</title>
</head>
<body>
    <p>Your email has now been validated, please return to your client. You may now close this window.</p>
</body>
</html>