/* Copyright 2019 New Vector Ltd
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

-- Tracks which identity server a user bound their threepid via.
CREATE TABLE user_threepid_id_server (
    user_id TEXT NOT NULL,
    medium TEXT NOT NULL,
    address TEXT NOT NULL,
    id_server TEXT NOT NULL
);

CREATE UNIQUE INDEX user_threepid_id_server_idx ON user_threepid_id_server(
    user_id, medium, address, id_server
);

INSERT INTO background_updates (update_name, progress_json) VALUES
  ('user_threepids_grandfather', '{}');
